==> fscolor-0.1.0.tar.gz: fscolor-0.1.0/README.md <==
# 🌈 fscolor - F-String Color Formatting for Python

[![PyPI Version](https://img.shields.io/pypi/v/fcolor.svg)](https://pypi.org/project/fscolor/)
[![Python Versions](https://img.shields.io/pypi/pyversions/fcolor.svg)](https://pypi.org/project/fscolor/)
[![License](https://img.shields.io/badge/license-MIT-blue.svg)](https://github.com/Kunlex58/fscolor/blob/main/LICENSE)


**fscolor** is a lightweight Python package that brings effortless color formatting to f-strings using ANSI escape codes. Designed for simplicity and readability, it enables developers to create vibrant console output with minimal code changes.

## Features ✨


- 🎨 **8 Basic Colors**: Black, Red, Green, Yellow, Blue, Magenta, Cyan, White
- 🔄 **Automatic Reset**: No need to manually reset colors

- 💻 **Cross-Platform**: Works on most modern terminals
- 🚀 **Zero Dependencies**: Pure Python implementation

- 📦 **F-String Ready**: Designed specifically for Python 3.6+ formatted strings
- 🔧 **Extensible Architecture**: Easily add custom colors or styles

## Installation 📦

```bash
pip install fscolor
```

## Use Cases

Examples - See [Jupyter Notebook](https://github.com/Kunlex58/fstrcolor/blob/main/LICENSE) for various use cases.


## Compatibility Notes ⚠️


- Requires terminal supporting ANSI escape codes  
- Colors may appear different based on terminal theme  

- Not recommended for file output or non-TTY devices  

## Roadmap 🗺️


- 256-color support  
- Background colors  

- Text styles (bold, italic, underline)  
- Windows compatibility layer  

## Contributing 🤝

Contributions welcome! Please check later for details.

## License 📄

MIT License - See [LICENSE](https://github.com/Kunlex58/fstrcolor/blob/main/LICENSE) for details.

==> fscolor-0.1.2.tar.gz: fscolor-0.1.2/README.md <==
# 🌈 fscolor - F-String Color Formatting for Python

[![PyPI Version](https://img.shields.io/pypi/v/fscolor.svg)](https://pypi.org/project/fscolor/)
[![Python Versions](https://img.shields.io/pypi/pyversions/fscolor.svg)](https://pypi.org/project/fscolor/)
[![License](https://img.shields.io/badge/license-MIT-blue.svg)](https://github.com/Kunlex58/fscolor/blob/main/LICENSE)


**fscolor** is a lightweight Python package that brings effortless color formatting to f-strings using ANSI escape codes. Designed for simplicity and readability, it enables developers to create vibrant console output with minimal code changes.

## Features ✨


- 🎨 **8 Basic Colors**: Black, Red, Green, Yellow, Blue, Magenta, Cyan, White
- 🔄 **Automatic Reset**: No need to manually reset colors

- 💻 **Cross-Platform**: Works on most modern terminals
- 🚀 **Zero Dependencies**: Pure Python implementation

- 📦 **F-String Ready**: Designed specifically for Python 3.6+ formatted strings
- 🔧 **Extensible Architecture**: Easily add custom colors or styles

## Installation 📦

```bash
pip install fscolor
```

## Use Cases

Examples - See [Jupyter Notebook](https://github.com/Kunlex58/fscolor/blob/main/fscolor.ipynb) for various use cases.


## Compatibility Notes ⚠️


- Requires terminal supporting ANSI escape codes  
- Colors may appear different based on terminal theme  

- Not recommended for file output or non-TTY devices  

## Roadmap 🗺️


- 256-color support  
- Background colors  

- Text styles (bold, italic, underline)  
- Windows compatibility layer  

## Contributing 🤝

Contributions welcome! Please check later for details.

## License 📄

MIT License - See [LICENSE](https://github.com/Kunlex58/fstrcolor/blob/main/LICENSE) for details.
